@@ -859,6 +859,8 @@ SEXP phi_to_theta_xptr(std::string fstr) {
     return(Rcpp::XPtr<p2tPtr>(new p2tPtr(&pp_phi_to_theta))) ;
   else if (fstr == "kgaps")
     return(Rcpp::XPtr<p2tPtr>(new p2tPtr(&kgaps_phi_to_theta))) ;
+  else if (fstr == "dgaps")
+    return(Rcpp::XPtr<p2tPtr>(new p2tPtr(&kgaps_phi_to_theta))) ;
   else
     return(Rcpp::XPtr<p2tPtr>(R_NilValue)) ;
 }
@@ -1229,12 +1231,36 @@ double kgaps_logpost(const Rcpp::NumericVector& x, const Rcpp::List& pars) {
   return loglik + logprior ;
 }
 
+// D-gaps
+
+// [[Rcpp::export]]
+double dgaps_logpost(const Rcpp::NumericVector& x, const Rcpp::List& pars) {
+  if (x[0] < 0 || x[0] > 1)
+    return R_NegInf ;
+  int N0 = pars["N0"] ;
+  int N1 = pars["N1"] ;
+  double sum_qtd = pars["sum_qtd"] ;
+  double q_u = pars["q_u"] ;
+  double D = pars["D"] ;
+  double loglik = 0.0 ;
+  if (N1 > 0)
+    loglik = loglik + 2 * N1 * log(x[0]) - sum_qtd * x[0] ;
+  if (N0 > 0)
+    loglik = loglik + N0 * log(1 - x[0] * exp(-x[0] * q_u * D)) ;
+  double alpha = pars["alpha"] ;
+  double beta = pars["beta"] ;
+  double logprior = (alpha - 1) * log(x[0]) + (beta - 1) * log(1 - x[0]) ;
+  return loglik + logprior ;
+}
+
 // [[Rcpp::export]]
 SEXP kgaps_logpost_xptr(std::string fstr) {
   typedef double (*logpostPtr)(const Rcpp::NumericVector& x,
                   const Rcpp::List& pars) ;
   if (fstr == "kgaps")
     return(Rcpp::XPtr<logpostPtr>(new logpostPtr(&kgaps_logpost))) ;
+  else if (fstr == "dgaps")
+    return(Rcpp::XPtr<logpostPtr>(new logpostPtr(&dgaps_logpost))) ;
   else
     return(Rcpp::XPtr<logpostPtr>(R_NilValue)) ;
 }
@@ -1255,6 +1281,8 @@ SEXP log_j_xptr(std::string fstr) {
                   const Rcpp::List& user_args) ;
   if (fstr == "kgaps")
     return(Rcpp::XPtr<p2tPtr>(new p2tPtr(&kgaps_log_j))) ;
+  else if (fstr == "dgaps")
+    return(Rcpp::XPtr<p2tPtr>(new p2tPtr(&kgaps_log_j))) ;
   else
     return(Rcpp::XPtr<p2tPtr>(R_NilValue)) ;
 }
